nmfkc.denormalize: Denormalize a matrix from [0,1] back to its original scale

View source: R/nmfkc.R

nmfkc.denormalizeR Documentation

Denormalize a matrix from [0,1] back to its original scale

Description

nmfkc.denormalize rescales a matrix with values in [0,1] back to its original scale using the column-wise minima and maxima of a reference matrix.

Usage

nmfkc.denormalize(x, ref = x)

Arguments

x

A numeric matrix (or vector) with values in [0,1] to be denormalized.

ref

A reference matrix used to obtain the original column-wise minima and maxima. Must have the same number of columns as x.

Value

A numeric matrix with values transformed back to the original scale.

See Also

nmfkc.normalize

Examples

x <- nmfkc.normalize(iris[, -5])
x_recovered <- nmfkc.denormalize(x, iris[, -5])
apply(x_recovered - iris[, -5], 2, max)

nmfkc documentation built on July 14, 2026, 1:07 a.m.