plot.nmfae: 'plot.nmfae' displays the convergence trajectory of the...

View source: R/nmfae.R

plot.nmfaeR Documentation

plot.nmfae displays the convergence trajectory of the objective function across iterations. The title shows the achieved R^2.

Description

plot.nmfae displays the convergence trajectory of the objective function across iterations. The title shows the achieved R^2.

Usage

## S3 method for class 'nmfae'
plot(x, ...)

Arguments

x

An object of class "nmfae" returned by nmfae.

...

Additional graphical parameters passed to plot.

Value

Invisible NULL. Called for its side effect (plot).

See Also

nmfae, nmfae.heatmap

Examples


set.seed(1)
Y <- matrix(runif(20), nrow = 4)
res <- nmf.rrr(Y, rank1 = 2)
plot(res)


nmfkc documentation built on July 14, 2026, 1:07 a.m.