plot.nmfae.ecv: Plot method for nmfae.ecv objects

View source: R/nmfae.R

plot.nmfae.ecvR Documentation

Plot method for nmfae.ecv objects

Description

Visualizes element-wise cross-validation results. When rank.encoder was NULL (paired), a line plot of sigma vs rank is drawn. When rank.encoder was explicitly specified (grid), a heatmap of sigma over the (rank, rank.encoder) grid is drawn.

Usage

## S3 method for class 'nmfae.ecv'
plot(x, ...)

Arguments

x

An object of class "nmfae.ecv" returned by nmfae.ecv.

...

Additional graphical parameters (currently unused).

Value

Invisible NULL. Called for its side effect of producing a plot.

See Also

nmfae.ecv


nmfkc documentation built on July 14, 2026, 1:07 a.m.