plot.nmfkc: Plot method for objects of class 'nmfkc'

View source: R/nmfkc.R

plot.nmfkcR Documentation

Plot method for objects of class nmfkc

Description

plot.nmfkc produces a diagnostic plot for the return value of nmfkc, showing the objective function across iterations.

Usage

## S3 method for class 'nmfkc'
plot(x, ...)

Arguments

x

An object of class nmfkc, i.e., the return value of nmfkc.

...

Additional arguments passed to the base plot function.

Value

Called for its side effect (a plot). Returns NULL invisibly.

See Also

nmfkc, summary.nmfkc

Examples

Y <- matrix(cars$dist, nrow = 1)
A <- rbind(1, cars$speed)
result <- nmfkc(Y, A, rank = 1)
plot(result)


nmfkc documentation built on July 14, 2026, 1:07 a.m.