Produces a summary of a fitted NMF-AE model with inference results, including the coefficients table for \(\Theta\).
Usage
# S3 method for class 'nmfae.inference'
summary(object, ...)Produces a summary of a fitted NMF-AE model with inference results, including the coefficients table for \(\Theta\).
# S3 method for class 'nmfae.inference'
summary(object, ...)