Produces a summary of a fitted NMF model with inference results, including the coefficients table for \(C\) (\(\Theta\)).
Usage
# S3 method for class 'nmfkc.inference'
summary(object, ...)Produces a summary of a fitted NMF model with inference results, including the coefficients table for \(C\) (\(\Theta\)).
# S3 method for class 'nmfkc.inference'
summary(object, ...)