Produces a summary of a symmetric NMF model with inference results, including the coefficients table for \(C\).
Usage
# S3 method for class 'nmfkc.net.inference'
summary(object, ...)Produces a summary of a symmetric NMF model with inference results, including the coefficients table for \(C\).
# S3 method for class 'nmfkc.net.inference'
summary(object, ...)