| nmf.rrr.inference | R Documentation |
Performs post-estimation inference for \Theta in the three-layer NMF model
Y_1 \approx X_1 \Theta X_2 Y_2, conditional on (\hat{X}_1, \hat{X}_2).
Uses sandwich covariance estimation and one-step wild bootstrap with
non-negative projection.
nmf.rrr.inference(object, Y1, Y2 = Y1, wild.bootstrap = TRUE, ...)
object |
An object of class |
Y1 |
Output matrix |
Y2 |
Input matrix |
wild.bootstrap |
Logical. If |
... |
Additional arguments:
|
An object of class c("nmfae.inference", "nmfae"), inheriting all
components from the input object, with additional inference components:
sigma2.used |
Estimated |
C.se |
Sandwich standard errors for |
C.se.boot |
Bootstrap standard errors for |
C.ci.lower |
Lower CI bounds for |
C.ci.upper |
Upper CI bounds for |
coefficients |
Data frame with Estimate, SE, BSE, z, p-value for each element of |
C.p.side |
P-value type used. |
This function is experimental. The interface may change in future versions; details are to be described in an upcoming paper.
nmfae, summary.nmfae.inference
Y <- matrix(c(1,0,1,0, 0,1,0,1, 1,1,0,0), nrow=3, byrow=TRUE)
res <- nmf.rrr(Y, rank1=2, rank2=2)
res2 <- nmf.rrr.inference(res, Y)
summary(res2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.