nmfkc.ar.stationarity assesses the dynamic stability of a VAR model
by computing the spectral radius of its companion matrix.
It returns both the spectral radius and a logical indicator of stationarity.
Value
A list with components:
- spectral.radius
Numeric. The spectral radius of the companion matrix. A value less than 1 indicates stationarity.
- stationary
Logical.
TRUEif the spectral radius is less than 1 (i.e., the system is stationary),FALSEotherwise.