nmfkc.ar.stationarity: Check stationarity of an NMF-VAR model

View source: R/nmfkc.ar.R

nmfkc.ar.stationarityR Documentation

Check stationarity of an NMF-VAR model

Description

nmfkc.ar.stationarity assesses the dynamic stability of a VAR model by computing the spectral radius of its companion matrix. It returns both the spectral radius and a logical indicator of stationarity.

Usage

nmfkc.ar.stationarity(x)

Arguments

x

The return value of nmfkc for a VAR model.

Value

A list with components:

spectral.radius

Numeric. The spectral radius of the companion matrix. A value less than 1 indicates stationarity.

stationary

Logical. TRUE if the spectral radius is less than 1 (i.e., the system is stationary), FALSE otherwise.

See Also

nmfkc, nmfkc.ar

Examples

# Check stationarity of fitted AR model
d <- AirPassengers
ar_data <- nmfkc.ar(d, degree = 2)
result <- nmfkc(ar_data$Y, ar_data$A, rank = 1)
nmfkc.ar.stationarity(result)


nmfkc documentation built on July 14, 2026, 1:07 a.m.