| nmfkc.ar.stationarity | R Documentation |
nmfkc.ar.stationarity assesses the dynamic stability of a VAR model
by computing the spectral radius of its companion matrix.
It returns both the spectral radius and a logical indicator of stationarity.
nmfkc.ar.stationarity(x)
x |
The return value of |
A list with components:
spectral.radius |
Numeric. The spectral radius of the companion matrix. A value less than 1 indicates stationarity. |
stationary |
Logical. |
nmfkc, nmfkc.ar
# Check stationarity of fitted AR model
d <- AirPassengers
ar_data <- nmfkc.ar(d, degree = 2)
result <- nmfkc(ar_data$Y, ar_data$A, rank = 1)
nmfkc.ar.stationarity(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.