| nmfkc.denormalize | R Documentation |
[0,1] back to its original scalenmfkc.denormalize rescales a matrix with values in [0,1] back to its
original scale using the column-wise minima and maxima of a reference matrix.
nmfkc.denormalize(x, ref = x)
x |
A numeric matrix (or vector) with values in |
ref |
A reference matrix used to obtain the original column-wise minima
and maxima. Must have the same number of columns as |
A numeric matrix with values transformed back to the original scale.
nmfkc.normalize
x <- nmfkc.normalize(iris[, -5])
x_recovered <- nmfkc.denormalize(x, iris[, -5])
apply(x_recovered - iris[, -5], 2, max)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.