| nmfkc.net.inference | R Documentation |
Performs statistical inference on the parameter matrix C of a
symmetric NMF model (Y \approx XCX^\top).
This is a wrapper around nmfkc.inference that automatically
sets the covariate matrix to A = X^\top, which is the defining
property of symmetric NMF.
nmfkc.net.inference(object, Y, wild.bootstrap = TRUE, ...)
object |
A fitted model returned by |
Y |
The original symmetric matrix (P x P). |
wild.bootstrap |
Logical; if TRUE (default), perform wild bootstrap inference for the C matrix. |
... |
Additional arguments passed to |
The object augmented with inference fields
(same as nmfkc.inference), with class
c("nmfkc.net.inference", "nmfkc.inference", "nmf.inference", "nmfkc", "nmf").
This function is experimental. The interface may change in future versions; details are to be described in an upcoming paper.
nmfkc.inference, nmfkc.net.DOT,
summary.nmfkc.net.inference
library(nmfkc)
Y <- matrix(c(0,1,1,0,0,0,
1,0,1,0,0,0,
1,1,0,1,0,0,
0,0,1,0,1,1,
0,0,0,1,0,1,
0,0,0,1,1,0), 6, 6)
res <- nmfkc.net(Y, rank = 2, type = "tri", nstart = 20)
res_inf <- nmfkc.net.inference(res, Y)
summary(res_inf)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.