| nmfkc.normalize | R Documentation |
[0,1]nmfkc.normalize rescales the values of a matrix to lie between 0 and 1
using the column-wise minimum and maximum values of a reference matrix.
nmfkc.normalize(x, ref = x)
x |
A numeric matrix (or vector) to be normalized. |
ref |
A reference matrix from which the column-wise minima and maxima are taken.
Default is |
A matrix of the same dimensions as x, with each column rescaled to the [0,1] range.
nmfkc.denormalize
# Example.
x <- nmfkc.normalize(iris[,-5])
apply(x,2,range)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.