| nmfkc.signed.cv | R Documentation |
Column-wise k-fold CV by held-out samples: for each
fold, the model is fit on the training columns and evaluated on the
held-out columns by solving for new-sample coefficients via a
weighted refit with X fixed.
nmfkc.signed.cv(Y, A, rank = 2, ...)
Y |
Real-valued |
A |
Real-valued |
rank |
Integer |
... |
Passed to |
A list with objfunc (mean squared prediction error),
sigma (RMSE), objfunc.block (per-fold MSE vector),
block (integer fold assignment of length N). Field
names match nmfkc.cv.
This function is experimental.
Ding, C. H. Q., Li, T., & Jordan, M. I. (2010). Convex and semi-nonnegative matrix factorizations. IEEE Transactions on Pattern Analysis and Machine Intelligence, 32(1), 45–55.
nmfkc.signed, nmfkc.signed.ecv
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.