plot.nmfae displays the convergence trajectory of the objective function across iterations. The title shows the achieved \(R^2\).
Source: R/nmfae.R
plot.nmfae.Rdplot.nmfae displays the convergence trajectory of the objective function
across iterations. The title shows the achieved \(R^2\).
Usage
# S3 method for class 'nmfae'
plot(x, ...)Arguments
- x
An object of class
"nmfae"returned bynmfae.- ...
Additional graphical parameters passed to
plot.