| plot.nmfae | R Documentation |
plot.nmfae displays the convergence trajectory of the objective function
across iterations. The title shows the achieved R^2.plot.nmfae displays the convergence trajectory of the objective function
across iterations. The title shows the achieved R^2.
## S3 method for class 'nmfae'
plot(x, ...)
x |
An object of class |
... |
Additional graphical parameters passed to |
Invisible NULL. Called for its side effect (plot).
nmfae, nmfae.heatmap
set.seed(1)
Y <- matrix(runif(20), nrow = 4)
res <- nmf.rrr(Y, rank1 = 2)
plot(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.