| plot.nmfae.ecv | R Documentation |
Visualizes element-wise cross-validation results.
When rank.encoder was NULL (paired), a line plot of sigma vs rank is drawn.
When rank.encoder was explicitly specified (grid), a heatmap of sigma over the (rank, rank.encoder) grid is drawn.
## S3 method for class 'nmfae.ecv'
plot(x, ...)
x |
An object of class |
... |
Additional graphical parameters (currently unused). |
Invisible NULL. Called for its side effect of producing a plot.
nmfae.ecv
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.