Skip to contents

Plots the objective function value over iterations for nmfre and nmf.sem objects. (For nmfkc and nmfae, plot methods are defined in their respective source files.)

Usage

# S3 method for class 'nmfre'
plot(x, ...)

# S3 method for class 'nmf.sem'
plot(x, ...)

Arguments

x

A fitted model object.

...

Additional graphical arguments passed to plot.

Value

Invisible NULL.

See also

Examples

# \donttest{
set.seed(1)
Y <- matrix(runif(20), nrow = 4)
A <- diag(5)
res <- nmfre(Y, A, rank = 2, wild.bootstrap = FALSE)
plot(res)

# }