| print.summary.nmfae.signed.inference | R Documentation |
Prints the Signed-Bottleneck NMF-AE summary followed by the coefficients table of Theta.
## S3 method for class 'summary.nmfae.signed.inference'
print(
x,
digits = max(3L, getOption("digits") - 3L),
by = c("covariate", "basis"),
...
)
x |
An object of class |
digits |
Minimum number of significant digits. |
by |
Character; grouping order of the coefficients table.
|
... |
Additional arguments (currently unused). |
Called for its side effect (printing). Returns x invisibly.
This function is experimental. The interface may change in future versions.
Ding, C. H. Q., Li, T., & Jordan, M. I. (2010). Convex and semi-nonnegative matrix factorizations. IEEE Transactions on Pattern Analysis and Machine Intelligence, 32(1), 45–55.
summary.nmfae.signed.inference
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.