Displays a concise summary of an NMF-RE model fit, including dimensions, convergence, variance components, and a coefficient table following standard R regression output conventions.
Usage
# S3 method for class 'nmfre'
summary(object, show_ci = FALSE, ...)Arguments
- object
An object of class
nmfre, returned bynmfre.- show_ci
Logical. If
TRUE, show confidence interval columns (defaultFALSE).- ...
Additional arguments (currently unused).
Examples
Y <- matrix(cars$dist, nrow = 1)
A <- rbind(intercept = 1, speed = cars$speed)
res <- nmfre(Y, A, rank = 1, maxit = 5000)
summary(res)
#> NMF-RE: Y(1,50) = X(1,1) [C(1,2) A + U(1,50)]
#> Iterations: 4 (converged, epsilon = 1e-05)
#> R-squared: 0.9047 (XB+blup), 0.6005 (XB)
#>
#> Variance components:
#> sigma2 = 1 (residual)
#> tau2 = 1 (random effect)
#> lambda = 1 (sigma2 / tau2)
#> ICC = 0.5000 (tau2*tr(X'X) / (tau2*tr(X'X) + sigma2*P))
#> dfU = 25.00 <= 30.00 (cap rate = 0.60)
#>
#> Coefficients:
#> Estimate Std. Error (Boot) z value Pr(>z)
#> intercept:Basis1 0.014 6.427 3.254 0.00 0.4991
#> speed:Basis1 2.851 0.456 0.432 6.25 2.118e-10 ***
#> ---
#> Signif. codes: 0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1